      SUBROUTINE CPGASTT(N,X,Z,TI,TS,TF,CL,NPA,PER,PN,AMP,CP,Z0)
C
C     CALCULA NORMALIZED POWER, PN, AMPLITUD, AMP, y FASE, PHA
C     ADEMAS, CALCULA PNN (SUBRUTINA  HOC))
C
C     PARAMETROS DE ENTRADA
C         X(I) --- Vector de posiciones
C         Z(I) --- Vector de datos
C         ITS ---- Tipo de serie
C         TB ----- Periodo inicia de analisis
C         TS ----- Discretizacion de periodos
C         TE ----- Periodo final de analisis
C
C     PARAMETROS DE SALIDA
C         SIM --- Segmento de analisis
C         PER --- Vector de periodos
C         FRE --- Vector de frecuencia lineal
C         PN ---- Normalized Power
C         CP ---- CUMULATIVE Power
C         AMP ---          Amplitud
C         PHA ---          Fase
C         Z0 ---- Confidence Level
C         PNN --- Normalized Power above CL
C         AMPN -- Amplitude above CL
C
C  In output : SIM, PER, FRE, PN, AMP, PHA, Z0, PNN, AMPN
C
      DOUBLE PRECISION X(N),Z(N),FM(NPA),AMP(NPA),PHA(NPA),PER(NPA),
     *FRE(NPA),PN(NPA),CP(NPA)
      INTEGER NN,NPA,NUN
      DOUBLE PRECISION PI2,CS,SN,OMG,TAC,TAS,TAU,OMEGA,CL,Z0,AMEAN,
     *SIGMA2,TI,TS,TF,AN1,SAV,ZS,SAVC1,SAVC2,SAVS1,SAVS2,OMEGAT
C
 1000 FORMAT(F12.5)
 2000 FORMAT(7F12.5)
C
      PI2=8.0D0*DATAN(1.0D0)
C
C  Evala que no haya demasiadas faltas de datos
C
      NN=N
      Z0=0.
C      NPA=1+((TF-TI)/TS)
      DO J=1,NPA
        PER(J)=TI+TS*(J-1)
        FM(J)=1/PER(J)
      ENDDO
C
C  Calcula el Confidence Level, Z0
C
      AN1=1.0D0/(DFLOAT(NN))
      Z0=-DLOG(1.0D0-CL**AN1)
C
C  Calcula the zero mean values Z(I)=Z(I)-amean and SIGMA
C
      SAV=0.0D0
      DO 10 I=1,NN
      SAV=SAV+Z(I)
   10 CONTINUE
      AMEAN=SAV/(DFLOAT(NN))
C
      DO 20 I=1,NN
      Z(I)=Z(I)-AMEAN
   20 CONTINUE
c
      ZS=0.
      DO 30 I=1,NN
      ZS=ZS+Z(I)*Z(I)
   30 CONTINUE
      SIGMA2=ZS/(DFLOAT(NN-1))
C
      SAV=0.0D0
      DO 60 J=1,NPA
      OMG=PI2*FM(J)
      CS=0.0D0
      SN=0.0D0
C
C   CALCULO de TAU
C
      TAC=0.0D0
      TAS=0.0D0
      DO 40 I=1,NN
      OMEGA=OMG*X(I)
      TAC=TAC+DCOS(OMEGA*2.0D0)
      TAS=TAS+DSIN(OMEGA*2.0D0)
   40 CONTINUE
      TAU=DATAN2(TAS,TAC)
      TAU=TAU/(OMG*2.0D0)
C
C   Calculo de los terminos Coseno y Seno, CS, SN
C
      SAVC1=0.0D0
      SAVC2=0.0D0
      SAVS1=0.0D0
      SAVS2=0.0D0
      DO 50 I=1,NN
      OMEGAT=OMG*(X(I)-TAU)
      SAVC1=SAVC1+Z(I)*DCOS(OMEGAT)
      SAVS1=SAVS1+Z(I)*DSIN(OMEGAT)
      SAVC2=SAVC2+(DCOS(OMEGAT))**2.0D0
      SAVS2=SAVS2+(DSIN(OMEGAT))**2.0D0
   50 CONTINUE
      SAVC2=DSQRT(SAVC2)
      SAVS2=DSQRT(SAVS2)
      CS=DSQRT(2.0D0/(DFLOAT(NN)))*(SAVC1/SAVC2)
      SN=DSQRT(2.0D0/(DFLOAT(NN)))*(SAVS1/SAVS2)
C
C   Calculo de PN, AMP, PHA, PER, FRE, PNN, AMPN
C
      PN(J)=(CS*CS+SN*SN)*(DFLOAT(NN))/(4.0D0*SIGMA2)
      SAV=SAV+PN(J)
      CP(J)=SAV
      AMP(J)=DSQRT(CS*CS+SN*SN)
      PHA(J)=DATAN2(SN,CS)
      PER(J)=1.0D0/FM(J)
      FRE(J)=FM(J)
C      FRE(J)=(10**9.0D0)*(FM(J)*FCP)/(FCF*3600.0D0)
   60 CONTINUE
C
C      WRITE(1,1000) AMEAN
C
   70 CONTINUE
C      WRITE(1,2000) (TI,PER(J),FRE(J),PN(J),AMP(J),PHA(J),Z0, J=1,NPA)
      RETURN
      END
