C     ROUTINE VelCorTim
C
C     COMPUTES CROSS-CORRELATION FUNCTION OF TIME SERIES:
C     X(I) AND Y(I)
C
C     INPUT PARAMETERS
C     COOR(I,2) - STATION COORDINATES
C     X(I) - TIME SERIES 1
C     Y(I) - TIME SERIES 2
C     KK   - NUMBER OF STATIONS OR TIME SERIES
C     NN   - NUMBER OF DATA OF THE TIME SERIES
C     LL   - MAXIMUM DISPLACEMENT (M-LAG)
C
C     OUTPUT PARAMETERS
C     AR(I) - VARIANCE FUNCTION X(J)
C     AS(I) - VARIANCE FUNCTION Y(J)
C     R(I)  - CROSSCORRELATION FUNCTION X(J)-Y(J)
C     S(I)  - CROSSCORRELATION FUNCTION Y(J)-X(J)
C     G(I)  - CROSSCORRELATION FUNCTION X&Y
C     LI(I) - DISPLACEMENT (LAG)
C
C     SUBROUTINE REQUIRED:
C           VARI AND CROSS (((ALL OF THEM IN THE MAIN)))
C                 WRITTEN BY APOSTOLOV,1991
C                 MODIFIED BY DAVID, 2018.09.21
CC
C      ELMER ROUTINES ADDED AS SOURCE FILES TO COMPILE
C            These are part of "lapack" a "lblas" libraries.
C            Elmer software is licensed under GPL .
C
C            dpptrf.f
C            dpptri.f
C            dspmv.f
C            ddot.f
C            dscal.f
C            dspr.f
C            dtpmv.f
C            dtpsv.f
C            dtptri.f
C            lsame.f
C            xerbla.f
C
C
C      OUTPUT
C          R - Y LAGS X
C          S - Y LEADS X
C     G(I)  - CROSSCORRELATION FUNCTION X&Y
C     LI(I) - DISPLACEMENT (LAG)
C     LIM   - DISPLACEMENT OF MAXIMUM CROSS-CORRELATION
C     CCM   - MAXIMUM CROSS-CORRELATION
C
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION COOR(15,2),X(500),Y(500),R(250),S(250),G(250),LI(250),
     *KI(15),CCM(15),DIFT(15),PESO(15),DIST(15,2),A(15,2),ATY(2),
     *VA(15),SL(2),XX(15,500),ISTA(15),NSTU(15),AR(250),AS(250),NET(15)
C
      CHARACTER*56 HEAD
      CHARACTER*12 ATIM
      CHARACTER*5 EST,ESTA(15),ESTR,ESTU(15),EX1
      CHARACTER*4 EX2
      CHARACTER*11 NAMO
      CHARACTER*23 NA1(20),NA2(20)
      CHARACTER*5 P
C
      INTEGER IS,NS,NN,LL,MM,KK,LIM,IDAT,IJ,KD,IFL,IHE,Pmain
C
 1000 FORMAT(56A)
 2000 FORMAT(I1,1X,A5,1X,A12,2F6.2,2I2)
 2500 FORMAT(A5)
 3000 FORMAT(19X,F8.2,8X)
 4000 FORMAT('ESRef ST   LAT    LON    VEL  AZI   ResiduS')
 5000 FORMAT(A5,I3,2F7.2,2I3,I6,I5,1X,F11.1)
 6000 FORMAT('ESCor ST  LAT    LON   LAG CrCoMa   Pes')
 7000 FORMAT(A5,1X,A5,I3,2F7.2,I4,F8.4,F7.4)
 8000 FORMAT (I5)
C
C     DATA NEEDED
C

      G2R=DATAN2(1.0D0,1.0D0)/45.0D0
      NN=360
      N60=300
      LL=61
      MM=2*LL-1
      EX1='R.dat'
      EX2='.Vel'
      NAMO='TIDsVel.dat'
C
C     READING DATA
C
      OPEN(1,FILE='inici2',STATUS='OLD')
      READ(1,1000) HEAD
      NS=0
   10 READ(1,2000,END=100) IFL,EST,ATIM,ALA,ALO,IHE,IS
      IF (IFL.EQ.0) GOTO 10
      NS=NS+1
      ESTA(NS)=EST
      ISTA(NS)=IS
C     IHE indicates the network, 1 Europe, 2 SouthAfrica
C     Due the poor number of stations in 2 conditions in 
C     2 are less restritive
C     NUM_CORR is the number of stations with correlation
C     greater than 0.5
      IF (IHE.EQ.1) NUM_CORR=3
      IF (IHE.EQ.2) NUM_CORR=2 
C      NET(NS)=IHE
      NA1(NS)=EST//'_'//ATIM//EX1
      COOR(NS,1)=ALO
      COOR(NS,2)=ALA
      NA2(NS)=EST//EX2
      GOTO 10
  100 CONTINUE
      CLOSE(1)
C
      DO 150 J=1,NS
      OPEN(1,FILE=NA1(J),STATUS='OLD')
      READ(1,3000) (XX(J,I),I=1,NN)
      CLOSE(1)
  150 CONTINUE
C
C     OPEN EXIT FILE
C
      OPEN(1,FILE=NAMO,STATUS='UNKNOWN')
C     FILE TO STORE CORRELATION RESULTS, NOT NEEDED
      OPEN(2,FILE='correl.log',STATUS='UNKNOWN')
C
C     INITIALIZING VARIABLES FOR DIFFERENT REFERENCE STATIONS
C
      DO 400 K=1,NS
      VMOD=-9999.0D0
      AZIM=-9999.0D0
      RESI=-9999.0D0
C
C     VECTORS X and Y FOR CALCULATION OF CROSS-CORR FROM
C        DATA MATRIX XX
C
         DO 200 I=61,NN
         X(I-60)=XX(K,I)
         CALL VARI(X,N60,LL,AR)
  200    CONTINUE
      KD=0
      KKKK=0
         DO 300 J=1,NS
C         IF(J.NE.K .AND. NET(J).EQ.NET(K)) THEN
         IF(J.NE.K ) THEN
            DO 210 I=61,NN
            Y(I-60)=XX(J,I)
  210       CONTINUE
         CALL VARI(Y,N60,LL,AS)
C
C     CALCULATION CROSS-CORRELATION
C
         CALL CROSS(X,Y,N60,LL,R,S)
            DO 220 I=1,LL
            CC=AR(I)*AS(I)
            R(I)=R(I)/DSQRT(CC)
            S(I)=S(I)/DSQRT(CC)
  220       CONTINUE
C
C     CALCULATION OF THE DISPLACEMENT INDEX LI(I)
C
         KK=-LL+1
            DO 230 I=1,LL
            G(I)=S(LL-I+1)
            LI(I)=KK
            KK=KK+1
  230       CONTINUE
C
            DO 240 I=2,LL
            G(LL+I-1)=R(I)
            LI(LL+I-1)=KK
            KK=KK+1
  240       CONTINUE
C
C     CALCULATION OF MAXIMUM CROSS-CORRELATION (CCM), ITS DISPLACEMNENT (LIM),
C             TIME DIFERENCE (DIFT), AND
C             THE WEIGHT OF THE CORRELATION IN THE INVERSION MATRIX.
C
C     "To avoid border effects, weight equal to 0 when the
C      maximum correlation is close to the window border".
C
         LIM=-999
         CCRM=-999.0D0
            DO 250 I=1,MM
            IF (G(I).GT.CCRM) THEN
            LIM=LI(I)
            CCRM=G(I)
            ENDIF
  250       CONTINUE
C
C      LOOKING FOR CASES WITH CCM > 0.5
C
         IF (CCRM.gt.0.5) KKKK=KKKK+1 
         KD=KD+1

         KI(KD)=LIM
         CCM(KD)=CCRM
         DIFT(KD)=DFLOAT(LIM)*60.0D0
         PESO(KD)=CCRM**2
         IF(LIM**2.EQ.(LL-1)**2) THEN
         PESO(KD)=0.0D0
C         KD=KD-1
         IF (CCRM.gt.0.5) KKKK=KKKK-1 
         ENDIF 
C
C    INITIALIZATING THE INVERSION MATRIX
C
            DO 260 I=1,15
            VA(I)=0.D0
  260       CONTINUE
C
            DO 270 I=1,2
            ATY(I)=0.D0
  270       CONTINUE
C
C    CALCULATION OF DISTANCES FROM THE REFERENCE STATION "K"
C
         DIST(J,1)=116.4D0*DCOS(COOR(K,2)*G2R)*(COOR(J,1)-COOR(K,1))
         A(KD,1)=DIST(J,1)
         DIST(J,2)=116.4D0*(COOR(J,2)-COOR(K,2))
         A(KD,2)=DIST(J,2)
         NSTU(KD)=J
         ESTU(KD)=ESTA(J)
C
C
       ENDIF
  300    CONTINUE
C
C   IF THE NUMBER OF STATIONS INVOLVED IN THE CALCULATION 
C   IS LESS THAN 3 GOTO 400, SKIP THE INVERSION CALCULATION
       IF (KD.lt.NUM_CORR) GOTO 400

C
C     CALCULATION SLOWNESS
C
CC       Inversion
C
         DO 330 L=1,KD
            DO 320 J=1,2
            ATY(J)=ATY(J)+A(L,J)*DIFT(L)*PESO(L)
               DO 310 I=1,J
               IJ=J*(J-1)/2+I
               VA(IJ)=VA(IJ)+A(L,I)*A(L,J)*PESO(L)
  310          CONTINUE
  320       CONTINUE
  330    CONTINUE
C
      CALL dpptrf('U',2,VA,ier1)
      CALL dpptri('U',2,VA,ier2)
      CALL dspmv('U',2,1.D0,VA,ATY,1,0.D0,SL,1)
C
CC        End Inversion
C
C     CALCULATION RESIDUAL
C
      RESI=0.0D0
         DO 350 L=1,KD
         SAV=0.0D0
            DO 340 J=1,2
            SAV=SAV+A(L,J)*SL(J)
  340       CONTINUE
         RESI=RESI+((DIFT(L)-SAV)*PESO(L))**2
  350    CONTINUE
      RESI=DSQRT(RESI/DFLOAT(KD))
C
C     CALCULATION RESULTS
C
      VMOD=1000.0D0/DSQRT(SL(1)**2+SL(2)**2)
      AZIM=90.D0-DATAN2(SL(2),SL(1))/G2R
      ESTR=ESTA(K)
      IF(AZIM.LT.0.0D0) AZIM=AZIM+360.0D0
      IF(VMOD.GT.5000) THEN
      VMOD=-999
      AZIM=-999
      ENDIF
C
C     WRITING RESULTS
C
C      WRITE(1,4000)
  500 WRITE(1,5000) ESTR,K,COOR(K,2),COOR(K,1),KD,KKKK,
     * INT(VMOD),INT(AZIM),RESI

C      NEEDED TO WRITE CORRELATION RESULTS        
CCC      WRITE(2,6000)
         DO 360 I=1,KD
      WRITE(2,7000) ESTR,ESTU(I),NSTU(I),COOR(NSTU(I),2),
     *  COOR(NSTU(I),1),KI(I),CCM(I),PESO(I)
  360 CONTINUE

  400 CONTINUE  !  (K)
CCC
      CLOSE(1)
      CLOSE(2)
CCC
CCC
      END
CCCCCC
CCCCCC
C         SUBROUTINE VARI
C
C     CALCULATE VARIANCE FUNCTION
C
C     PARAMETRES
C     A  -GIVEN VECTOR OF TIME SERIES DATA
C     N  -DIMENSION OF VECTOR A
C     L  -MAXIMUM LAG FOR AUTOCOVARIATION FUNCTION
C     R  -RESULTING VECTOR OF VARIANCE FUNCTION (DIMENSION L)
C
      SUBROUTINE VARI(A,N,L,R)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION A(500),R(250)
      INTEGER NI,NF
C
C
      IF(N-L) 50,50,100
   50 R(1)=0.0D0
      RETURN
  100 CONTINUE
C
C         CALCULATE VARIANCES
      DO 130 J=1,L
      NI=J
      SUM=0.0D0
         DO 120 I=NI,N
         SUM=SUM+(A(I)*A(I))
  120    CONTINUE
      R(J)=SUM
  130 CONTINUE
C
      RETURN
      END
CCCCCC
CCCCCC
C     SUBROUTINE CROSS
C
C     COMPUTES THE CROSSCOVARIANCES OF TIME SERIES A AND B
C
C     PARAMETERS
C         A,B -INPUT DATA SETS FOR TIME SERIES A AND B
C         N   -NUMBER OF DATA  N(A)=N(B)
C         L   -MAXIMUM LAG
C         R,S -CROSSCOVARIATION FUNCTIONS (R-B LAGS A, S-B LEADS A)
C
      SUBROUTINE CROSS(A,B,N,L,R,S)
      IMPLICIT DOUBLE PRECISION (A-H,O-Z)
      DIMENSION A(500),B(500),R(250),S(250)
C
      INTEGER NJ,IJ
C
C
      IF(N-L) 50,50,100
   50 R(1)=0.0
      S(1)=0.0
      RETURN
  100 CONTINUE
C
C         CALCULATE CROSSOVARIANCES OF SERIES A AND B
C
      DO 130 J=1,L
      NJ=N-J+1
      SUMR=0.0D0
      SUMS=0.0D0
         DO 120 I=1,NJ
         IJ=I+J-1
         SUMR=SUMR+(A(I)*B(IJ))
         SUMS=SUMS+(A(IJ)*B(I))
  120 CONTINUE
      R(J)=SUMR
      S(J)=SUMS
  130 CONTINUE
      RETURN
      END
