#!/usr/bin/tcsh

#reading date from the keyboard 
# ./main_HFI_INT_TechTIDE.sh "initial date-time" "final date-time"
#initial date and final date-time in the format YYYY-MM-DD HH:mm
set date_i = `date -d "$1" +'%s'`
set date_f = `date -d "$2" +'%s'`


#The variable $seconds will be used to make the method repetitive
set seconds = `date --date='@'{$date_i}'' +%s`

# IF instruction only controls that the final date-time is greater than the initial date-time
if ( $date_f > $date_i ) then
# while instruction makes the method repetitive
while ( $seconds <= $date_f )

#To download date we need to put the time variables in the properly format
#they have to be a 2-digits format, i.e. 00,05,...
set current_date = `date --date='@'{$seconds}''`
set year = `date -d "$current_date" +%Y`
set month = `date -d "$current_date" +%m`
set day = `date -d "$current_date" +%d`
set hour = `date -d "$current_date" +%H`
set minute = `date -d "$current_date" +%M`
set year_1 = `date -d "$current_date 1 day ago" +%Y`
set month_1 = `date -d "$current_date 1 day ago" +%m`
set day_1 = `date -d "$current_date 1 day ago" +%d`

#Create folder to store data and results
mkdir -p $year$month$day
cp stations.txt $year$month$day
cd $year$month$day

#selecting the network to work with, 1 means Europe, 2 means South Africa
#we start with Europe
set network = 1
#the while-structure allows us to change the network
while ( $network < 3 )

if ( $network == 1 ) then
set stas = ( "AT138" "DB049" "EB040" "FF051" "JR055" "PQ052" "RL052" "RO041" "SO148" "VT139" )
#numstacoh is the number minimum of stations with coherent period that we demand to make some calculations 
set numstacoh = 3
endif
if ( $network == 2 ) then
set stas = ( "GR13L" "HE13N" "LV12P" "MU12K" )
#due the number of stations in this network, the minimum number of coherent stations is less restrictive
set numstacoh = 2
endif

#initialization of variables, num_sta_bad will be the number of stations with no enough data
# num_sta_nocoh will be the number of stations with period no coherent, we will use for indexs IQ and IR
@ num_sta_bad = 0
@ num_sta_nocoh = 0


#header of file input for the residual and period calculation
echo ' IFLAG ESTA yyyymmddhhmm ALATIN ALONGE IHE IST FORMAT(I1,1x,A5,1X,A12,2(F7.2),2I4)' >inici

	foreach sta ( $stas )
#In case of reprocessing downloaded data you can delete the coments of the following if
#if ( -e ${sta}_${year}${month}${day}${hour}${minute}.txt ) then
#echo ${sta}_${year}${month}${day}${hour}${minute}.txt
#else
#command to download data
curl "https://lgdc.uml.edu/common/DIDBGetValues?ursiCode="$sta"&charName=foF2,MUFD&DMUF=3000&fromDate="$year_1"%2F"$month_1"%2F"$day_1"+"$hour"%3A"$minute"%3A30&toDate="$year"%2F"$month"%2F"$day"+"$hour"%3A"$minute"%3A30" -o $sta"_"$year$month$day$hour$minute.txt
#endif
#Start of data control
if ( -Z ${sta}_${year}${month}${day}${hour}${minute}.txt < 900  ) then
@ flag = 0
@ num_sta_bad = $num_sta_bad + 1
else
[ -e INI ] && rm INI
echo ' ESTA ALATIN ALONGE ICHAR FORMAT(A18,2(1X,F6.2),1X,I5)' >>INI
grep $sta stations.txt | gawk '{print "'${sta}'""_""'${year}'""'${month}'""'${day}'""'${hour}'""'${minute}'",$2,$3}' >>INI
set percent = `../data_size.out`
rm INI

if ( $percent < 80 ) then
@ flag = 0
@ num_sta_bad = $num_sta_bad + 1
else 
@ flag = 1
endif
endif

#create file inici needed for residual and period calculation
grep $sta stations.txt | gawk '{print "'${flag}'","'${sta}'","'${year}'""'${month}'""'${day}'""'${hour}'""'${minute}'",$2,$3,$4,$5}' >>inici

end

#Residual calculation
../calculateR.out

#Period calculation
../period.out
cat inici >> inici3
rm inici


#looking for the dominant period
set pav = `../checkp.out`

#keep in memory, pmig the dominant period, num stations with coherent period pcoh
set pcoh = $pav[10]
set pmig = $pav[11]
set delta = $pav[12]
set indexA = $pav[13]
set domina = $pav[9]
@ inti = $pmig - $delta
@ intf = $pmig + $delta

#header of inici2 input file for program correl.out
echo ' IFLAG ESTA yyyymmddhhmm ALATIN ALONGE IHE IST FORMAT(I1,1x,A5,1X,A12,2(F7.2),2I4)' >inici2

#If the number of stations with coherent period if greater than 3 make the rest of calculations else write -999
if ( $pcoh > $numstacoh ) then

#Selection of the coherent stations
foreach sta ( $stas )
grep $sta TID.log |gawk '{print $9,$10}' > per.log
set p = `cat per.log`
#echo $p
if ( $%p > 0 ) then
set p1 = $p[2]
else
@ p1 = 0
endif
if ( $%p > 4 ) then
set p2 = $p[4]
else
@ p2 = 0
endif

if ( ( $p1 != 0 && $p1 >= $inti && $p1 <= $intf ) || ( $p2 != 0 && $p2 >= $inti && $p2 <= $intf ) ) then
@ ifl = 1
else
@ ifl = 0
@ num_sta_nocoh = $num_sta_nocoh + 1
endif

#writing file inici2, flag 1 for coherent stations, flag 0 for the non-coherent
grep $sta stations.txt | gawk '{print "'${ifl}'","'${sta}'","'${year}'""'${month}'""'${day}'""'${hour}'""'${minute}'",$2,$3,$4,$5}' >>inici2
end
rm per.log

#correlation, velocity and azimuth calculation
../correl.out

#fill stations non-coherent with -999
foreach sta ( $stas )
grep $sta TIDsVel.dat | gawk '{print $1,$5,$6,$7,$8}' > Vels.log
if ( -Z Vels.log > 5 ) then
cat Vels.log >> Vel_Azi.log
else
grep $sta stations.txt | gawk '{print "'{$sta}'",0,0,-999,-999}' >> Vel_Azi.log
endif
rm Vels.log
end

#reading files TID.log and Vel_Azi.log we put all results together and stablish a warning level
#the final result TID_HFI_YYYYMMDDHHMM.log

../warning_level.out $pmig $indexA $domina $num_sta_bad $num_sta_nocoh

#comes from the first if (pcoh>=3)
else
foreach sta ( $stas )
if ( -e $sta'_'$year$month$day$hour$minute'R.dat' ) then
@ h = 1
else
@ h = 0
endif
grep $sta stations.txt | gawk '{print $4,$5,"'{$h}'","'{$sta}'","'{$year}'""'{$month}'""'{$day}'""'{$hour}'""'{$minute}'",$2,$3,0,0,0,"0.000","0.0000","0.0000",-999,-999,"'{$h}'",0,0}' >> TID_HFI.log
end
endif

#header for the final file
if ( $network == 1 ) then
echo 'NT ST FL STA DATE&TIME  ALAI ALONG  NW IW PERIO POWER AMPLI SPCONT VEL AZI TrL IQ IR' > TID_HFI_${year}${month}${day}${hour}${minute}.log
endif
#we check the previous instance of time to see the statbility in velocity and azimuth
foreach sta ( $stas )
grep $sta TID_HFI.log | gawk '{print $14,$15,$16}' > sem_vel_azi.log
set isem_vel_azi = `cat sem_vel_azi.log`
set isem = $isem_vel_azi[3]
set vel = $isem_vel_azi[1]
set azi = $isem_vel_azi[2]

if ( $isem >= 2 ) then
if ( -e previous_file_$network.log ) then
grep $sta previous_file_$network.log |gawk '{print $14,$15,$16}' > sem_vel_azi_ant.log
if ( -s sem_vel_azi_ant.log ) then
set isem_vel_azi_ant = `cat sem_vel_azi_ant.log`
set isem_ant = $isem_vel_azi_ant[3]
set vel_ant = $isem_vel_azi_ant[1]
set azi_ant = $isem_vel_azi_ant[2]

@ delta_azi = 45
@ azi_i = $azi_ant - $delta_azi
@ azi_f = $azi_ant + $delta_azi

if ( $azi_i < 0 ) then
@ azi_i = 0
@ azi_f = 360
endif
if ( $azi_f > 360 ) then
@ azi_i = 0
@ azi_f = 360
endif

if ( $azi >= $azi_i && $azi <= $azi_f ) then
grep $sta TID_HFI.log |gawk '{print $1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11,$12,$13,$14,$15,$16,$17,$18}' >> TID_HFI_${year}${month}${day}${hour}${minute}.log
else
grep $sta TID_HFI.log |gawk '{print $1,$2,$3,$4,$5,$6,$7,$8,$9,0,"0.000","0.0000","0.0000",-999,-999,1,0,0}' >> TID_HFI_${year}${month}${day}${hour}${minute}.log
endif

else
grep $sta TID_HFI.log |gawk '{print $1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11,$12,$13,$14,$15,$16,$17,$18}' >> TID_HFI_${year}${month}${day}${hour}${minute}.log
endif

else
grep $sta TID_HFI.log |gawk '{print $1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11,$12,$13,$14,$15,$16,$17,$18}' >> TID_HFI_${year}${month}${day}${hour}${minute}.log
endif

else
grep $sta TID_HFI.log |gawk '{print $1,$2,$3,$4,$5,$6,$7,$8,$9,$10,$11,$12,$13,$14,$15,$16,$17,$18}' >> TID_HFI_${year}${month}${day}${hour}${minute}.log
endif

end
cat TID_HFI.log > previous_file_$network.log

[ -e correl.log ] && rm correl.log
rm TID_HFI.log
rm TID.log
rm sem_vel_azi.log
[ -e sem_vel_azi_ant.log ] && rm sem_vel_azi_ant.log
[ -e Vel_Azi.log ] && rm Vel_Azi.log
[ -e TIDsVel.dat ] && rm TIDsVel.dat
rm inici2
#comes from the while ($network < 3) and allow us to change the network to work with
@ network = $network + 1

end
rm stations.txt

../globalActInd.out
rm TID_HFI_${year}${month}${day}${hour}${minute}.log

set starm = ( "AT138" "DB049" "EB040" "FF051" "JR055" "PQ052" "RL052" "RO041" "SO148" "VT139" "GR13L" "HE13N" "LV12P" "MU12K")
foreach star ( $starm )
[ -e ${star}_${year}${month}${day}${hour}${minute}R.dat ] && rm ${star}_${year}${month}${day}${hour}${minute}R.dat
end

rm inici3

#comes from the while ($seconds <= date_f) we add 5 minutes to $seconds
@ seconds = $seconds + 300

cd ..

end

#if initial date is greater than the final date
else
echo 'Be careful! The initial date is greater than the final date'
endif
