C     ROUTINE CPGAOSTT
C
C     COMPUTES PERIODOGRAMS OF (Correloperiodogram) of TIME SERIES Z
C     (FROM 1 TO N) in a desirable periodic range
C
C     SUBRUTINAS NECESARIAS:
C       CPGASTT (NO LA FUENTE). First version WRITTEN BY APOSTOLOV,1996.
C       ADAPTADA por David para TechTIDE Abril de 2018.
C
C       BUSCAMAXP - DAVID 2018
C       CONESPOR -- DAVID 2018
C       ORDENA ---- DAVID 2018
C
C            --> Se aplica a residuos (CADENCIA DE UN MINUTO).
C            --> Exige Probabilidad PRO.GE.0.975.
C            --> Selecciona Perodo mximo dominante.
C            --> Determina variabilidad
C
C     FOR OTHER PARAMETERS SEE SUBROUTINE CPGASTT
C
C
C     VECTORES, VARIABLES y DATOS
C
C        X(I) ----> Vector de posiciones de la serie de datos
C                   CONFIGURADO PARA SERIES EQUIDISTANTES,
C                   PUEDE OPERAR CON SERIES NO EQUIDISTANTES
C        Z(I) ----> Vector de inicial de la serie de datos
C        PP(I) ---> Vector de PERIODOS
C        PR(I) ---> Vector de PROBABILIDADES
C        AM(I) ---> Vector de AMPLITUDES
C        CCP(I) --> Vector de CONTRIBUCION CUMULATIVA DE POTENCIA ESPECTRAL
C
C        TI ------> Periodo inicial de analisis (MINUTOS)
C        TS ------> Fraccion de periodo de analisis
C        TF ------> Periodo final de analisis
C
C        TIB -----> Periodo inicial de BUSQUEDA
C                   OJO TIB > TI+IR
C        TFB -----> Periodo final de BUSQUEDA
C                   OJO TFB < TF-IS
C
C        PEM -----> PERIODO DE MAXIMA AMPLITUD
C        POM -----> POTENCIA ESPECTRAL DE PEM
C        AMM -----> AMPLITUD DE PEM
C        CEP -----> CONTRIBUCION ESPECTRAL PORCENTUAL
C
C        NDS -----> Numero de Datos de la Serie (Dimension Z(I))
C        NPA -----> Numero de Periodos Analizados (Dimension PE(I))
C        NIB -----> POSICION inicial de BUSQUEDA
C        NFB -----> POSICION final de BUSQUEDA
C
C
C     OTROS PARAMETROS
C
C        CLE --- Confidence Level
C        PCS --- POTENCIA DE CONFIDENCIA SIGNIFICATIVA (> o = CLE)
C        IHE --- INDICADOR DE HEMISFERIO
C        IST --- INDICADOR DE ESTACION
C        ESTA -- CODIGO URSI DE LA ESTACIN DE ANALISIS
C        ALATI - LATITUD GEODETICA
C        ALONG - LONGITUD GEODETICA
C        MM ---- NUMERO DE MAXIMOS LOCALES
C        FL ---- INDICADOR DE POSIBLE TID (0 = NO, 1 = SI)
C        IR ---- RANGO DE PERIODOS RESTADOS A PEM PARA EL CALCULO DE
C                CONTRIBUCION ESPECTRAL PORCENTUAL
C        IS ---- RANGO DE PERIODOS SUMADOS A PEM PARA EL CALCULO DE
C                CONTRIBUCION ESPECTRAL PORCENTUAL
C
C
      DOUBLE PRECISION Z(1000),X(1000),PE(500),PO(500),AM(500),CCP(500)
      DOUBLE PRECISION PEM(100),POM(100),AMM(100),CEP(100)
      DOUBLE PRECISION  TI,TS,TF,TIB,TFB,CLE,ALATI,ALONG,PCS
      INTEGER NDS,NPA,IHE,IST,MM,IR,IS,IFLAG,P(100)
C
      CHARACTER*5 ESTA,EXTI,EXTO
      CHARACTER*12 TIME
      CHARACTER*40 HEAD
      CHARACTER*23 NAMI,NAMO
      CHARACTER*5 TEMPS,ESTACIO
      
C
C
 1100 FORMAT (A8)
 1000 FORMAT(I1,1X,A5,1X,A12,2F6.2,2I3) 
 2000 FORMAT(19X,F8.2,8X)
 3000 FORMAT(I4,F6.1,F10.3,F9.4,F9.3,F11.3)
 4000 FORMAT(3I3,1X,A5,1X,A12,2F7.2,2I3,I5,F10.3,2F9.4)
 4400 FORMAT(3I3,1X,A5,1X,A12,2F7.2,2I3,F6.1,F10.3,2F9.4
     * ,1X,I1,2F7.0)
 5000 FORMAT(2F12.4)
 6000 FORMAT(F12.4)
 7000 FORMAT(I5,F8.2)
 8000 FORMAT(6X,I1,6X,F6.0,1X,F6.0)
C
C   DATA NEEDED
C
      EXTI='R.dat'
      EXTO='E.dat'
      NDS=360
      TI=30.
      TS=1.
      TF=210.
      TIB=37.
      TFB=150.
      CLE=0.975
      NPA=((TF-TI)/TS)+1
      NIB=TIB-TI+1
      NFB=TFB-TI+1
C
C     IR and IS are dynamics calculated with subroutine ConEsPor
C
      DO 20 I=1,NDS
      X(I)=I
   20 CONTINUE

C
C  READ NAME OF DATA FILE

      OPEN(3,FILE='inici',STATUS='OLD')
      READ(3,1100) HEAD
      OPEN(4,FILE='TID.log',STATUS='UNKNOWN')
      WRITE(4,*) 'HE ST FL  ESTA   DATE  TIME  ALATI  ALONG NW IW PERIO
     * POTENCIA   AMPLI    CONTP  SEM  VEL  AZI'
   50 READ(3,1000,END=999) IFLAG,ESTA,TIME,ALATI,ALONG,IHE,IST
       IFLAG=INT(IFLAG)
       IHE=INT(IHE)
       IST=INT(IST)
      IF (IFLAG.EQ.0) THEN
      WRITE(4,4000) IHE,IST,0,ESTA,TIME,ALATI,ALONG,0,0,0,0.,0.,0.
      GOTO 50
      ENDIF      
C
      NAMI=ESTA//'_'//TIME//EXTI
      NAMO=ESTA//'_'//TIME//EXTO
C
C   DATA READING
C
      OPEN(2,FILE=NAMI,STATUS='OLD')
      READ(2,2000) (Z(I),I=1,NDS)
      CLOSE(2)
C
C   CALCULATION PERIODOGRAM
C
      CALL CPGASTT(NDS,X,Z,TI,TS,TF,CLE,NPA,PE,PO,AM,CCP,PCS)
C
C   WRITING SPECTRAL FOR INDIVIDUAL STATIONS, NOT NEEDED
C
C      OPEN(1,FILE=NAMO,STATUS='UNKNOWN')
C      WRITE(1,3000) (I,PE(I),PO(I),AM(I),PCS,CCP(I),I=1,NPA)
C      CLOSE(1)
C
C   LOOK FOR LOCAL MAXIMUM INSIDE SPECTRUM
C
      CALL BUSCAMAXP(NPA,PE,PO,AM,PCS,NIB,NFB,MM,PEM,POM,AMM)
C
C   WRITE RESULTS OF LOCAL MAXIMUMS
C
    
      IF(POM(1).LT.0) THEN
      P=INT(PEM)
      WRITE(4,4000) IHE,IST,1,ESTA,TIME,ALATI,ALONG,0,0,P(1),0.,AMM(1)
     *,0.
      GOTO 50
      ENDIF
C
C   CALCULATION OF THE SPECTRAL CONTRIBUTION
C
      CALL CONESPOR(NPA,CCP,MM,PEM,TI,CEP)
C
C   ARRANGE BY PERIODS
C
      CALL ORDENA(PEM,MM,POM,AMM,CEP)
      DO I=1,MM
      P=INT(PEM)
      WRITE(4,4000) IHE,IST,1,ESTA,TIME,ALATI,ALONG,MM,I,P(I),POM(I),
     *AMM(I),CEP(I)
      ENDDO
      GOTO 50
C
  999 CONTINUE
      CLOSE(3)
      CLOSE(4)
      STOP
      END
