C     ROUTINE warning_level  !!!
C
C    This program read files TID.log and Vel_Azi.log
C    generated by programs period.out and correl.out respectively.
C    TID.log contains information about period, spectral 
C    contribution, power and so more...
C    Vel_Azi.log contains number of stations with correlation
C    greater than 0.5, velocity and azimuth
C    This program take all data and put it all together and
C    stablish a warning level based on spectral contribution,
C    index of quality and range index.
C    The output file is TID_HFI.log
C

      DOUBLE PRECISION  ALATI(30),ALONG(30)
      DOUBLE PRECISION  AMP(30),POT(30),CONT(30)
      INTEGER NUMCORR(10),VEL(10),AZI(10),PER(30),isem,IA(10),KD(10)
      integer IHE(30),IST(30),IFL(30),NW(30),IW(30),idom,delta,nodata 
C
      CHARACTER*5 ESTA(30),ESTA_REF(10),P,PP,PPP,PPPP,QQQ
      CHARACTER*12 TIME(30)
      i=1
      j=1
      ni=0
      nj=0
C
 1000 FORMAT(A97)
 3000 FORMAT(A5,2I2,I5,I5)
 4000 FORMAT(3I3,1X,A5,1X,A12,2F7.2,2I3,I5,F10.3,2F9.4)
 4400 FORMAT(3I3,1X,A5,1X,A12,2F7.2,2I3,I5,F10.3,2F9.4
     * ,1X,2I5,I2,1X,I3,1X,I3)
 5000 FORMAT(F5.0)
 6000 FORMAT(I1)

C     INPUT FROM THE BASH FILE
      call getarg (1,P)
      call getarg (2,PP)
      call getarg (3,PPP)
      call getarg (4,PPPP)
      call getarg (5,QQQ)
C     Pmain is de dominant period
      read(P,5000) Pmain
C     abast is the number of stations with coherent period
      read(PP,5000) abast
C     idom indicates which period (1 or 2) is the dominant 
C     for a single station
      read(PPP,6000) idom
C     nodata is the number of stattions with not enough data
      read(PPPP,6000) nodata
C     nocoh is the number of stations with non coherent period
      read(QQQ,6000) nocoh 
      delta=int(Pmain*0.3)

C     opening the output file
      OPEN(4,FILE='TID_HFI.log',STATUS='UNKNOWN')

C     opening and reading input files Vel_Azi.log and TID.log
      OPEN(2,FILE='Vel_Azi.log',STATUS='OLD')
    6 READ(2,3000,END=998) ESTA_REF(i),KD(i),NUMCORR(i),VEL(i),AZI(i)
      i=i+1
      GOTO 6
  998 CONTINUE
      ni=i-1
      OPEN(1,FILE='TID.log',STATUS='OLD')
      READ(1,1000) HEAD	
    5 READ(1,4000,END=999) IHE(j),IST(j),IFL(j),ESTA(j),TIME(j),
     * ALATI(j),ALONG(j),
     * NW(j),IW(j),PER(j),POT(j),AMP(j),CONT(j) 
      j=j+1
C     Checking which network we are going to work with
C     1 means Europe
C     2 means SouthAfrica, due to the poor number 
C     of stations in 2, the conditions are less restrictive
C     MINCORR is the minimum number of stations with 
C     correlation greater then 0.5
      IF (IHE(1).EQ.1) MINCORR=3
      IF (IHE(1).EQ.2) MINCORR=2
      GOTO 5
  999 CONTINUE
      nj=j-1 

C     COMPARE THE 2 FILES
C     IFL indicates: 1 data, 0 no data
C     NW indicates: 0 no period, 1 one period, 2 two periods
C     IW indicates which period 1 or 2
C     Depending on IFL, NW and IW values we asign warning level
C     and indexs

      do 100 i=1,ni
      do 200 j=1,nj

C     isem is the warning level, 1 quiet, 2 moderate
C     and 3 severe activity
      isem=1
       
      if (ESTA(j).eq.ESTA_REF(i) ) then
C     In case of no data (IFL=0) warning level=0 
      if (IFL(j).eq.0) then 
      WRITE(4,4400) IHE(j),IST(j),IFL(j),ESTA(j),TIME(j),
     * ALATI(j),ALONG(j),0,0,0,0.,0.,0.,-999,-999,0,0,0   
      else
C     In case of no period (NW=0) warning level=1
      if (NW(j).eq.0) then
      WRITE(4,4400) IHE(j),IST(j),IFL(j),ESTA(j),TIME(j),
     * ALATI(j),ALONG(j),NW(j),0,0,0.,0.,0.,-999,-999,1,0,0   
      else
C     In case of non coherenrent period warning level=1
C     NW will be 1 or 2 but IW=0 
      if (IW(j).eq.idom .or. NW(j).eq.1 ) then
      if (PER(j).lt.Pmain-delta .or. PER(j).gt.Pmain+delta) then  
      WRITE(4,4400) IHE(j),IST(j),IFL(j),ESTA(j),TIME(j),
     * ALATI(j),ALONG(j),NW(j),0,0,0.,0.,0.,-999,-999,1,0,0   
      else
C     In case of coherent period but not enough stations 
C     with good correlation, warning level=1
C     NW will be 1 or 2 but IW=9 to identify bad correlation 
      if (NUMCORR(i).lt.MINCORR) then
      WRITE(4,4400) IHE(j),IST(j),IFL(j),ESTA(j),TIME(j),
     * ALATI(j),ALONG(j),NW(j),9,0,0.,0.,0.,-999,-999,1,0,0   
      else
C     In case of coherent period and good correlation but
C     with non-realistic value of velocity, warning level=1
      if (VEL(i).gt.1800) then
      WRITE(4,4400) IHE(j),IST(j),IFL(j),ESTA(j),TIME(j),
     * ALATI(j),ALONG(j),NW(j),IW(j),0,0.,0.,0.,-999,-999,1,0,0   
      else
C     In case of coherent period, good correlation and 
C     realistic velocity we check the spectral contribution (CONT)
C     	 In case of poor CONT warning level=1
      if (CONT(j).lt.10) then
      WRITE(4,4400) IHE(j),IST(j),IFL(j),ESTA(j),TIME(j),
     * ALATI(j),ALONG(j),NW(j),IW(j),0,0.,0.,0.,-999,-999,1,0,0   
      else
C     	 In case of significant CONT we asign the warning level
      if (CONT(j).lt.18) isem=1
      if (CONT(j).ge.18 .and. CONT(j).lt.65) isem=2
      if (CONT(j).ge.65 .and. CONT(j).lt.80) isem=3
      if (CONT(j).ge.80 .and. CONT(j).lt.86) isem=4
      if (CONT(j).ge.86) isem=5
C        And we calculate indexs IQ and IA
      IA(i)=int(NUMCORR(i)*100/(ni-1-nocoh))
      IQ=int((ni-nodata)*100/ni)
      WRITE(4,4400) IHE(j),IST(j),IFL(j),ESTA(j),TIME(j),
     * ALATI(j),ALONG(j),NW(j),IW(j),PER(j),POT(j),AMP(j),
     * CONT(j),VEL(i),AZI(i),isem,IQ,IA(i)
      endif
      endif
      endif
      endif
      endif 
      endif 
      endif 
      ENDIF
  200 CONTINUE
  100 CONTINUE

      CLOSE(1)
      CLOSE(2)
      END
C
